@@ -28,7 +28,7 @@ def run_main():
                         help='idiom', default="All")
     parser.add_argument('--outputdir', type=str,
                         help='outputdir', default="./RefactoringIdiomsOutputdir/")
-    parser.add_argument('--flag_merge_allcodepair', type=str,
+    parser.add_argument('--flag_merge_allcodepair', type=int,
                         help='flag_merge_allcodepair', default=1)
     parser.add_argument('--output_codepair', type=str,
                         help='output_codepair', default="result.json")
