@@ -292,7 +292,7 @@ def transform_for_multiple_targets_code(content):
 
                         new_code_fragment_list[ind]=' '*e[0].col_offset+e_fragment
 
-                print("for multi targets ast.unparse(e[1]): ",ast.unparse(e[1]))
+                # print("for multi targets ast.unparse(e[1]): ",ast.unparse(e[1]))
                 # code_pair_list.append([class_name,me_name,[old_node_content], [ast.unparse(e[1])],line_list])
                 code_pair_list.append([class_name,me_name,[old_node_content], ["\n".join(new_code_fragment_list)],line_list])
 
@@ -328,7 +328,7 @@ def get_for_multi_tar_part_fragment(content):
                 # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
                 # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
                 if 1:#target_node_str == ast.unparse(e[0]):
-                    print("come for multi targets")
+                    # print("come for multi targets")
                     old_node_content = ast.get_source_segment(content, e[0])
                     line_list=[[(e[0].lineno,e[0].col_offset),(e[0].end_lineno,e[0].end_col_offset)]]
 
