@@ -242,6 +242,37 @@ def get_chain_compare(content):
     except:
         traceback.print_exc()
         return code_pair_list
+
+def get_part_chain_compare(content):
+    code_pair_list=[]
+    # print(content)
+    try:
+
+        tree = ast.parse(content)
+        # ana_py = ast_util.Fun_Analyzer()
+        # ana_py.visit(file_tree)
+        # print("come here",ana_py.func_def_list)
+        if 1:
+        # for tree, class_name in ana_py.func_def_list:
+            # print("come method",ast.unparse(tree))
+            try:
+                me_name = tree.name
+            except:
+                me_name = ""
+            new_code_list = []
+            check_chained_comparison(tree, new_code_list)
+
+            for old_node,new_node in new_code_list:
+                old_node_content = ast.get_source_segment(content, old_node)
+
+                line_list=[[(old_node.lineno,old_node.col_offset), (old_node.end_lineno,old_node.end_col_offset)]]
+
+                code_pair_list.append(['',me_name,[old_node_content],[ast.unparse(new_node)],line_list])
+        return code_pair_list
+
+    except:
+        traceback.print_exc()
+        return code_pair_list
 # def save_repo_for_else_complicated(repo_name):
 #     start=time.time()
 #     count_complicated_code = 0
