@@ -288,7 +288,7 @@ def replace_code(lineno_list,simp_code, code_fragment_list, bias=0):
         if ind == len(lineno_list) - 1:
             new_code_fragment_list += code_fragment_list[end_row_new + 1:]
 
-        # print("each new_code_fragment_list: ", new_code_fragment_list)
+    # print("each new_code_fragment_list: ", new_code_fragment_list)
     return new_code_fragment_list
 def file_replace(abs_path, each_file_code_list):
 
@@ -346,8 +346,12 @@ def file_replace(abs_path, each_file_code_list):
                     lineno_list = each_code[-1]
                     # compli_code=chain_compare_code[-4]
                     simp_code = each_code[-3]
+                    # print(lineno_list,simp_code,code_fragment_list)
+
                     code_fragment_list = replace_code(lineno_list,simp_code, code_fragment_list,bias)
+                    # print("old_content: ","".join(new_content),pre_lineno,start_row, end_row)
                     new_content.extend(code_fragment_list)
+                    # print("new_content: ",code_fragment_list,"".join(new_content))
                 else:
                     # break
                     # if ind_each_code==0:
@@ -445,6 +449,10 @@ def file_replace(abs_path, each_file_code_list):
                         if ind_each_code == len(each_group_code) - 1:
                             new_content.extend(code_fragment_list)
                             # print(">>>*********new_content:\n", "".join(new_content))
+                        if pre_lineno:
+                            pre_lineno = max(start_row, pre_lineno[0]), max(end_row, pre_lineno[1])
+                        else:
+                            pre_lineno = start_row, end_row
                         continue
                     if not code_pair_list:
                         for ind_code_frag, e in enumerate(code_fragment_list):
@@ -453,7 +461,10 @@ def file_replace(abs_path, each_file_code_list):
                         if ind_each_code == len(each_group_code) - 1:
                             new_content.extend(code_fragment_list)
                             # print(">>>*********new_content:\n", "".join(new_content))
-
+                        if pre_lineno:
+                            pre_lineno = max(start_row, pre_lineno[0]), max(end_row, pre_lineno[1])
+                        else:
+                            pre_lineno = start_row, end_row
                         continue
                     # print("code_pair_list: ",code_pair_list)
                     new_lineno_list = code_pair_list[0][-1]
@@ -483,7 +494,7 @@ def file_replace(abs_path, each_file_code_list):
                     pre_lineno=max(start_row,pre_lineno[0]), max(end_row,pre_lineno[1])
                 else:
                     pre_lineno=start_row, end_row
-            if ind_group==len(each_group_code)-1:
+            if ind_group==len(group_new_sorted_code_list)-1:
                     new_content.extend(lines[pre_lineno[1]:])
 
 
@@ -546,9 +557,9 @@ def main(args):
             if os.path.exists(output_dir):
                 shutil.rmtree(output_dir)
             for ind_save, each_code_pair in enumerate(format_code_list):
-                print("come here")
+                # print("come here")
                 new_content = file_replace(filepath, [each_code_pair])
-                print("new_content: ",new_content)
+                # print("new_content: ",new_content)
                 util.save_file_path("".join([output_dir, "/", file_name[:-3], '_', str(ind_save), '.py']),
                                     new_content)
 
@@ -558,10 +569,10 @@ def main(args):
 
         else:
             new_content = file_replace(filepath, format_code_list)
-            print("new_content: ", new_content)
+            # print("new_content: ", new_content)
             if os.path.exists(output_dir):
                 shutil.rmtree(output_dir)
-            print("new_content: ", new_content)
+            # print("new_content: ", new_content)
             util.save_file_path("".join([output_dir, "/",file_name] ), new_content)
 
             # util.save_file_path()
@@ -575,12 +586,12 @@ if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='RefactoringIdioms')
     parser.add_argument('--envname', type=str,
                         help='envname', default="CartPole-v0")
-    # parser.add_argument('--filepath', type=str,
-    #                     help='filepath', default=abs_path+"/file.py")
+    parser.add_argument('--filepath', type=str,
+                        help='filepath', default=abs_path+"/file.py")
     # parser.add_argument('--filepath', type=str,
     #                     help='filepath', default=abs_path + "/")
-    parser.add_argument('--filepath', type=str,
-                        help='filepath', default= "./")
+    # parser.add_argument('--filepath', type=str,
+    #                     help='filepath', default= "./")
     # parser.add_argument('--filepath', type=str,
     #                     help='filepath', default="/Users/zhangzejunzhangzejun/PycharmProjects/code")
     #
@@ -596,7 +607,7 @@ if __name__ == '__main__':
     # parser.add_argument('--flag_merge_allcodepair', type=str,
     #                     help='flag_merge_allcodepair', default=1)
     parser.add_argument('--flag_merge_allcodepair', type=int,
-                        help='flag_merge_allcodepair', default=0)
+                        help='flag_merge_allcodepair', default=1)
     parser.add_argument('--output_codepair', type=str,
                         help='output_codepair', default="result.json")
     parser.add_argument('--flag_console_output', type=str,
