@@ -256,7 +256,7 @@ class RewriteName(ast.NodeTransformer):
         def generic_visit(self, node):
 
             if ast.unparse(node) in self.Map_var:
-                print("yes it need to replce:",node)
+                # print("yes it need to replce:",node)
                 if isinstance(node,ast.Expr):
                     return ast.Expr(self.Map_var[ast.unparse(node)])
                 else:
@@ -316,11 +316,11 @@ def transform_for_node_var_unpack(for_node,node_list,Map_var):
         #         print("yes: ", a)
         # print("transform_for_node_var_unpack_for_node:",ast.unparse(for_node))
         for_node.target = tuple
-        print("transform_for_node_var_unpack_for_node_target:",ast.unparse(for_node))
+        # print("transform_for_node_var_unpack_for_node_target:",ast.unparse(for_node))
 
         # tree = ast.parse('foo', mode='eval')
         new_tree = RewriteName(Map_var).visit(for_node)
-        print("transform new_tree:",ast.unparse(new_tree))
+        # print("transform new_tree:",ast.unparse(new_tree))
 
         return new_tree
     except:
